@@ -12,7 +12,7 @@ Init global parameters fixture function to load all the project necessary global
 """
 
 
-def before_all(app_config_path):
+def before_all():
     """
     Loads project global parameters and store them as pytest global variable, so the parameters will be accessible
     everywhere
@@ -20,7 +20,7 @@ def before_all(app_config_path):
 
     # Init Json properties
     # Opening JSON file
-    f = open(app_config_path)
+    f = open(pytest.user_dir + '/app-config.json')
     # Returns JSON object as a dictionary
     data = json.load(f)
     # Store the properties in pytest global variables
@@ -30,7 +30,7 @@ def before_all(app_config_path):
 
     # Init Tokens JSON data
     # Opening token JSON file
-    f = open(pytest.project_dir + "/testsData/tokens.json")
+    f = open(pytest.user_dir + 'testsData/tokens')
     # Returns JSON object as a dictionary
     tokens = json.load(f)
     # Store the data in pytest global variables
@@ -40,7 +40,7 @@ def before_all(app_config_path):
 
     # Init farms JSON data
     # Opening token JSON file
-    f = open(pytest.project_dir + "/testsData/farms.json")
+    f = open(farms_file_path)
     # Returns JSON object as a dictionary
     farms_data = json.load(f)
     # Store the data in pytest global variables
@@ -50,7 +50,7 @@ def before_all(app_config_path):
 
     # Init wallets JSON data
     # Opening token JSON file
-    f = open(pytest.project_dir + "/testsData/wallets.json")
+    f = open(wallets_file_path)
     # Returns JSON object as a dictionary
     wallets_data = json.load(f)
     # Store the data in pytest global variables
@@ -59,21 +59,10 @@ def before_all(app_config_path):
     f.close()
 
     # Initialize the logger instance.
-    with open(pytest.project_dir + "/Tests/logging.yaml", 'rt') as f:
+    with open(logging_file_path, 'rt') as f:
         config = yaml.safe_load(f.read())
     logging.config.dictConfig(config)
 
     # Get an instance of the logger and use it to write a log
     # Store the logger in pytest global variables
-    pytest.logger = logging.getLogger(__name__)
-
-
-def get_current_datetime():
-    """
-    init current datetime
-    @return date_time - current time
-    """
-    # Current date and time
-    current_time = datetime.datetime.now()
-    date_time = current_time.strftime("%d-%m-%Y %H-%M-%S")
-    return date_time
+    pytest.logger = logging.getLogger(__name__)
\ No newline at end of file
