@@ -1,5 +1,6 @@
+import datetime
+
 import pytest
-from src.seleniumPythonFramework_VeriSoft.fixtures.InitGlobalParameters import get_current_datetime
 
 """
 screenshots fixture function for screenshot of the test falling
@@ -10,7 +11,18 @@ after each test, if the test failed - take screenshot and store him with datetim
 """
 
 
-def after_test(request):
+def get_current_datetime():
+    """
+    init current datetime
+    @return date_time - current time
+    """
+    # Current date and time
+    current_time = datetime.datetime.now()
+    date_time = current_time.strftime("%d-%m-%Y %H-%M-%S")
+    return date_time
+
+
+def after_test(request, project_path):
     """
     Take screenshot when test fail, save it in screenshot folder with current datetime in file name
     :param request: the requesting test context
@@ -20,5 +32,6 @@ def after_test(request):
         # Get driver name
         driver_type = request.cls.driver.name
         # Save screenshot in target directory
-        request.cls.driver.save_screenshot(pytest.project_dir + '/target/screenshots/' + "SC " + get_current_datetime() + " " + driver_type + ".png")
-        pytest.logger.info("screenshot successfully taken")
\ No newline at end of file
+        request.cls.driver.save_screenshot(
+            pytest.project_dir + '/target/screenshots/' + "SC " + get_current_datetime() + " " + driver_type + ".png")
+        pytest.logger.info("screenshot successfully taken")
